Macro sqlx_type_macro::query_as
source · [−]query_as!() { /* proc-macro */ }Expand description
A variant of query! which takes a path to an explicitly defined struct as the output type.
This lets you return the struct from a function or add your own trait implementations.